@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::YANICK;
 our $AUTHORITY = 'cpan:YANICK';
-$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.31.0';
+$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.32.0';
 # ABSTRACT: Be like Yanick when you build your dists
 
 # [TODO] add CONTRIBUTING file
@@ -55,7 +55,7 @@ sub configure {
     my $arg = $self->payload;
 
     my $release_branch = $arg->{release_branch} || 'releases';
-    my $dev_branch     = $arg->{dev_branch}     || 'master';
+    my $dev_branch     = $arg->{dev_branch}     || 'main';
     my $upstream       = $arg->{upstream}       || 'github';
 
     my @import_from_build = $arg->{import_from_build} ? split( ',', $arg->{import_from_build} ) :
@@ -198,7 +198,7 @@ Dist::Zilla::PluginBundle::YANICK - Be like Yanick when you build your dists
 
 =head1 VERSION
 
-version 0.31.0
+version 0.32.0
 
 =head1 DESCRIPTION
 
@@ -286,7 +286,7 @@ his distributions. It's roughly equivalent to
     [UploadToCPAN]
 
     [Git::Push]
-        push_to = github master releases
+        push_to = github main releases
 
     [InstallRelease]
     install_command = cpanm .
@@ -349,9 +349,9 @@ off the changelog. Defaults to I<true>.
 
 =head3 dev_branch
 
-Master development branch.
+Main development branch.
 
-Defaults to C<master>.
+Defaults to C<main>.
 
 =head3 release_branch
 
